@@ -72,9 +72,13 @@ void run_long_timeout(AWallpaperPlugin *desktop_plugin);
 //void set_actor_visible(Actor *actor, gboolean visible);
 //void set_actor_scale(Actor *actor, double scalex, double scaley);
 void create_hildon_actor(Actor *actor, AWallpaperPlugin *desktop_plugin);
+void create_hildon_actor_text(Actor *actor, AWallpaperPlugin *desktop_plugin); 
 void get_sun_screen_pos(double alt, double azm, gint * x, gint * y);
 void show_settings(GtkWidget *widget, Animation_WallpaperPrivate *priv);
 void livewp_initialize_dbus(Animation_WallpaperPrivate *priv);
 void livewp_deinitialize_dbus(Animation_WallpaperPrivate *priv);
-static gboolean long_timeout (AWallpaperPlugin *desktop_plugin);
+gint current_active_view(void);
+gboolean long_timeout (AWallpaperPlugin *desktop_plugin);
+void desktop_plugin_visible_notify (GObject *object, GParamSpec *spec, AWallpaperPlugin *desktop_plugin);
+
 #endif
