@@ -1,4 +1,4 @@
-/*vim: set sw=4 ts=4 et: */
+/* vim: set sw=4 ts=4 et: */
 /*
  * This file is part of Live Wallpaper (livewp)
  * 
@@ -30,35 +30,235 @@ destroy_scene(AWallpaperPlugin *desktop_plugin)
     if (desktop_plugin->priv->scene){
 	    GSList * tmp = desktop_plugin->priv->scene->actors;
 	    while (tmp != NULL){
-		destroy_actor(tmp->data);
-		tmp = g_slist_next(tmp);
+		    destroy_actor(tmp->data);
+		    tmp = g_slist_next(tmp);
 	    }
 	    if (tmp)
-		g_slist_free(tmp);
+		    g_slist_free(tmp);
 	    desktop_plugin->priv->scene->actors = NULL;
 	    if (desktop_plugin->priv->scene){
-		g_free(desktop_plugin->priv->scene);
-		desktop_plugin->priv->scene = NULL;
+		    g_free(desktop_plugin->priv->scene);
+		    desktop_plugin->priv->scene = NULL;
 	    }
     }
+    if (desktop_plugin->priv->pipeline){
+        gst_element_set_state (desktop_plugin->priv->pipeline, GST_STATE_NULL);
+        gst_object_unref (GST_OBJECT (desktop_plugin->priv->pipeline));
+        desktop_plugin->priv->pipeline = NULL;
+    }
+    if (desktop_plugin->priv->podpid > 1){
+        kill (desktop_plugin->priv->podpid, SIGTERM);
+        desktop_plugin->priv->podpid = -1;
+    }
 }
-
+/*******************************************************************************/
 void
 reload_scene(AWallpaperPlugin *desktop_plugin)
 {
     fprintf(stderr,"Reload scene %s\n", desktop_plugin->priv->theme);  
     destroy_scene(desktop_plugin);
-#if 0
-    if (!strcmp(desktop_plugin->priv->theme,"Modern"))
-        init_scene_Modern(desktop_plugin);
-    else if (!strcmp(desktop_plugin->priv->theme,"Berlin")) 
-        init_scene_Berlin(desktop_plugin);
-    else if (!strcmp(desktop_plugin->priv->theme,"Matrix")) 
-        init_scene_Matrix(desktop_plugin);
-#endif
     init_scene_theme(desktop_plugin);
 }
+/*******************************************************************************/
+void 
+init_scene_Accel(AWallpaperPlugin *desktop_plugin)
+{
+    Actor *actor;
+    Scene *scene;
+    GPtrArray *child;
+    gint now = time(NULL);
+    gchar *str;
+    gint sizes1[4] = {57, 76, 43, 50},
+         n, j;
+    
+    fprintf(stderr, "init scene accel\n");
+    scene = g_new0(Scene, 1);
+    scene->actors = NULL;
+    desktop_plugin->priv->scene = scene;
+    
+    actor = init_object(desktop_plugin, "background", "bg.png", 
+                      0, 0, 0, 800, 480, 
+                      TRUE, TRUE, 100, 255, 
+                      NULL, NULL, NULL);
+    scene->actors = g_slist_append(scene->actors, actor);
 
+    child = g_ptr_array_sized_new(16);
+    
+    for (j= 0; j<4; j++){
+    for (n=0; n<4; n++){
+        str = g_strdup_printf("tape%i.png", n+1);
+        actor = init_object(desktop_plugin, "tape", str,
+                            fast_rnd(800), fast_rnd(480), 2+fast_rnd(6), 800, sizes1[n],
+                            TRUE, TRUE, 100, 255,
+                            NULL, NULL, NULL);
+        scene->actors = g_slist_append(scene->actors, actor);
+        g_ptr_array_add(child, actor);
+        g_free(str);
+    }
+    }
+    actor = init_object(desktop_plugin, "tape", "", 
+                      0, 800, 5, 800, 170, 
+                      FALSE, FALSE, 100, 255, 
+                      (gpointer)&change_tape, NULL, child);
+    actor->time_start_animation = now;
+    actor->duration_animation = G_MAXINT;
+    scene->actors = g_slist_append(scene->actors, actor);
+
+    run_long_timeout(desktop_plugin);
+}
+/*******************************************************************************/
+void  
+parsestring(char *line, char **argv)
+{
+   while (*line != '\0') {  
+          while (*line == ' ' || *line == '\n')
+                *line++ = '\0';     /* replace white spaces with 0    */
+                 *argv++ = line;          /* save the argument position     */
+                 while (*line != '\0' && *line != ' ' && 
+                        *line != '\n') 
+                     line++;             /* skip the argument until ...    */
+   }
+	          *argv = '\0';                 /* mark the end of argument list  */
+}
+
+#if 0
+GstBusSyncReply 
+sync_handler(GstBus *bus, GstMessage *message, AWallpaperPlugin *desktop_plugin){
+
+    if (!desktop_plugin->priv->visible)
+        gst_element_set_state (desktop_plugin->priv->pipeline, GST_STATE_PAUSED);
+    if (GST_MESSAGE_TYPE(message) != GST_MESSAGE_ELEMENT){
+		return (GST_BUS_PASS);
+	}
+    if (!gst_structure_has_name(message->structure, "prepare-xwindow-id")){
+        return (GST_BUS_PASS);
+    }
+    return (GST_BUS_DROP);
+
+}
+#endif
+/*******************************************************************************/
+static gboolean
+bus_call (GstBus *bus, GstMessage *msg, AWallpaperPlugin *desktop_plugin)
+{
+    switch (GST_MESSAGE_TYPE (msg))
+    {
+       case GST_MESSAGE_EOS: 
+           if (desktop_plugin->priv->rich_animation){
+
+                GstClockTime nach   = (GstClockTime)(0 * GST_MSECOND);
+                if (!gst_element_seek(desktop_plugin->priv->pipeline, 1.0, GST_FORMAT_TIME,
+                   (GstSeekFlags) (GST_SEEK_FLAG_FLUSH | GST_SEEK_FLAG_KEY_UNIT), GST_SEEK_TYPE_SET, 
+                   nach, GST_SEEK_TYPE_NONE, GST_CLOCK_TIME_NONE))
+                    fprintf(stderr,"ERROR in seek\n");
+
+                gst_element_set_state (desktop_plugin->priv->pipeline, GST_STATE_PLAYING);
+
+           }else{
+                if (desktop_plugin->priv->pipeline){
+                    gst_element_set_state (desktop_plugin->priv->pipeline, GST_STATE_NULL);
+                    gst_object_unref (GST_OBJECT (desktop_plugin->priv->pipeline));
+                } 
+           }
+           break;
+       case GST_MESSAGE_ERROR: break;
+       default: break;
+     }
+       return TRUE;
+}
+
+/*******************************************************************************/
+void
+init_scene_Xsnow(AWallpaperPlugin *desktop_plugin){
+    fprintf(stderr,"init_scene_Xsnow\n");
+    char* child_argv[128];
+    char *run_string = NULL;
+#if 0
+    fprintf(stderr, "PARAMETR %s\n",  desktop_plugin->priv->theme_string_parametr1);
+    run_string = g_strdup_printf("/usr/bin/mplayer -vo x11 -wid %d %s\n", \
+		                 GDK_WINDOW_XID(desktop_plugin->priv->window->window), desktop_plugin->priv->theme_string_parametr1);
+#endif
+    if (!desktop_plugin->priv->visible)
+        return;
+    run_string= g_strdup_printf("/usr/bin/xsnow");
+    parsestring(run_string, child_argv);
+
+    desktop_plugin->priv->running = TRUE;
+    desktop_plugin->priv->podpid = fork();
+    if (desktop_plugin->priv->podpid == 0){
+    	execvp("/usr/bin/xsnow", child_argv);
+    	fprintf(stderr,"Problem with new podprocess");
+    }
+    g_free(run_string);
+}
+/*******************************************************************************/
+gboolean cb_timeout0(AWallpaperPlugin *desktop_plugin) {
+    GstFormat fmt = GST_FORMAT_TIME;
+    gboolean test;
+    gint64 len;
+    gint len_seconds = 0;
+
+    if (!desktop_plugin || !desktop_plugin->priv->pipeline)
+        return FALSE;
+    if (desktop_plugin->priv->theme_int_parametr1 == 0){
+        if (!gst_element_seek(GST_PIPELINE (desktop_plugin->priv->pipeline), 1.0, GST_FORMAT_TIME,
+                                          GST_SEEK_FLAG_FLUSH, GST_SEEK_TYPE_SET, 
+                                          desktop_plugin->priv->theme_int_parametr1 * GST_SECOND,
+                                          GST_SEEK_TYPE_NONE, GST_CLOCK_TIME_NONE))
+            fprintf(stderr,"Error in seek:\n");
+        return FALSE;
+    }
+       
+    if (gst_element_get_state (desktop_plugin->priv->pipeline, NULL, NULL, -1) == GST_STATE_CHANGE_FAILURE) 
+        return TRUE;
+    else{
+         if (!gst_element_seek(GST_PIPELINE (desktop_plugin->priv->pipeline), 1.0, GST_FORMAT_TIME,
+                                          GST_SEEK_FLAG_FLUSH, GST_SEEK_TYPE_SET, 
+                                          desktop_plugin->priv->theme_int_parametr1 * GST_SECOND,
+                                          GST_SEEK_TYPE_NONE, GST_CLOCK_TIME_NONE))
+            fprintf(stderr,"Error in seek:\n");
+         return FALSE;
+    }
+} 
+/*******************************************************************************/
+void
+init_scene_Video(AWallpaperPlugin *desktop_plugin)
+{
+    GstElement *bin;                                                                                                                                                           
+    GstElement *videosink;                                                                                                
+    GstFormat format; 
+    gchar *file_plus_uri;
+
+
+    /* fprintf(stderr, "init scene Video \n"); */
+    desktop_plugin->priv->pipeline = gst_pipeline_new("gst-player");
+    bin = gst_element_factory_make ("playbin2", "bin");
+    videosink = gst_element_factory_make ("ximagesink", "videosink");
+    g_object_set (G_OBJECT (bin), "video-sink", videosink, NULL);
+    gst_bin_add (GST_BIN (desktop_plugin->priv->pipeline), bin);
+
+    {
+    	GstBus *bus;
+     	bus = gst_pipeline_get_bus (GST_PIPELINE (desktop_plugin->priv->pipeline));
+       	gst_bus_add_watch(bus, bus_call, desktop_plugin);
+    	gst_object_unref (bus);
+    }
+    file_plus_uri = g_strdup_printf("file://%s",desktop_plugin->priv->theme_string_parametr1);
+    g_object_set (G_OBJECT (bin), "uri", file_plus_uri, NULL );
+    g_object_set (G_OBJECT (videosink), "force-aspect-ratio", TRUE, NULL  );
+
+    if (GST_IS_X_OVERLAY (videosink))
+	    gst_x_overlay_set_xwindow_id (GST_X_OVERLAY (videosink), GDK_DRAWABLE_XID(desktop_plugin->priv->window->window));
+
+    if (desktop_plugin->priv->visible){
+        gst_element_set_state (desktop_plugin->priv->pipeline, GST_STATE_PLAYING);
+        g_timeout_add(100, cb_timeout0, desktop_plugin); 
+    }
+   
+    //gst_element_get_state(deskddtop_plugin->priv->pipeline, NULL, NULL, 100 * GST_MSECOND);
+
+}
+/*******************************************************************************/
 void
 init_scene_Matrix(AWallpaperPlugin *desktop_plugin)
 {
@@ -76,7 +276,7 @@ init_scene_Matrix(AWallpaperPlugin *desktop_plugin)
       y2 = -480;
   }
 
-  //fprintf(stderr, "init scene2 \n");
+  /* fprintf(stderr, "init scene2 \n"); */
   scene = g_new0(Scene, 1);
   //scene.daytime = get_daytime();
   scene->actors = NULL;
@@ -142,7 +342,7 @@ init_scene_Matrix(AWallpaperPlugin *desktop_plugin)
   run_long_timeout(desktop_plugin);
 
 }
-
+/*******************************************************************************/
 /* Init Modern Scene */
 void
 init_scene_Modern(AWallpaperPlugin *desktop_plugin)
@@ -154,7 +354,7 @@ init_scene_Modern(AWallpaperPlugin *desktop_plugin)
   gint winds[13][2];
   GPtrArray *child; 
 
-  //fprintf(stderr, "init scene \n");
+  /* fprintf(stderr, "init scene \n"); */
   scene = g_new0(Scene, 1);
   scene->daytime = get_daytime();
   scene->actors = NULL;
@@ -499,7 +699,7 @@ init_scene_Modern(AWallpaperPlugin *desktop_plugin)
   scene.dynamic_actors = g_slist_append(scene.dynamic_actors, anim);
 #endif  
 }
-
+/*******************************************************************************/
 /* Init Berlin Scene */
 void
 init_scene_Berlin(AWallpaperPlugin *desktop_plugin)
@@ -669,7 +869,7 @@ init_scene_Berlin(AWallpaperPlugin *desktop_plugin)
     run_long_timeout(desktop_plugin);
 
 }
-
+/*******************************************************************************/
 void 
 init_scene_theme(AWallpaperPlugin *desktop_plugin)
 {
